Struct SurfaceData
pub struct SurfaceData { /* private fields */ }Available on crate feature
wayland and Linux only.Expand description
Data associated with a WlSurface.
Implementations
impl SurfaceData
impl SurfaceData
pub fn new(parent_surface: Option<WlSurface>, scale_factor: i32) -> SurfaceData
pub fn new(parent_surface: Option<WlSurface>, scale_factor: i32) -> SurfaceData
Create a new surface that initially reports the given scale factor and parent.
pub fn scale_factor(&self) -> i32
pub fn scale_factor(&self) -> i32
The scale factor of the output with the highest scale factor.
pub fn parent_surface(&self) -> Option<&WlSurface>
pub fn parent_surface(&self) -> Option<&WlSurface>
The parent surface used for this surface.
The surface is Some for primarily for subsurfaces,
since they must have a parent surface.